@@ -1,7 +1,7 @@
 ///
 /// @file  Erat.hpp
 ///
-/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -15,14 +15,13 @@
 #include "EratMedium.hpp"
 #include "EratBig.hpp"
 #include "macros.hpp"
-#include "intrinsics.hpp"
 #include "Vector.hpp"
+#include "ctz.hpp"
 
 #include <stdint.h>
 
 namespace primesieve {
 
-class PreSieve;
 class MemoryPool;
 
 /// The abstract Erat class sieves primes using the segmented sieve
@@ -49,17 +48,15 @@ protected:
   Vector<uint8_t> sieve_;
   Erat() = default;
   Erat(uint64_t, uint64_t);
-  void init(uint64_t, uint64_t, uint64_t, PreSieve&, MemoryPool& memoryPool);
+  void init(uint64_t, uint64_t, uint64_t, MemoryPool& memoryPool);
   void addSievingPrime(uint64_t);
   NOINLINE void sieveSegment();
   bool hasNextSegment() const;
   static uint64_t nextPrime(uint64_t, uint64_t);
 
 private:
-  uint64_t maxPreSieve_ = 0;
   uint64_t maxEratSmall_ = 0;
   uint64_t maxEratMedium_ = 0;
-  PreSieve* preSieve_ = nullptr;
   EratSmall eratSmall_;
   EratBig eratBig_;
   EratMedium eratMedium_;
