@@ -1,7 +1,7 @@
 ///
 /// @file  EratSmall.hpp
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -12,7 +12,7 @@
 
 #include "Bucket.hpp"
 #include "macros.hpp"
-#include "pod_vector.hpp"
+#include "Vector.hpp"
 #include "Wheel.hpp"
 
 #include <cstddef>
@@ -28,12 +28,12 @@ class EratSmall : public Wheel30_t
 {
 public:
   void init(uint64_t, uint64_t, uint64_t);
-  void crossOff(pod_vector<uint8_t>& sieve);
+  void crossOff(Vector<uint8_t>& sieve);
   bool hasSievingPrimes() const { return !primes_.empty(); }
 private:
   uint64_t maxPrime_ = 0;
   std::size_t l1CacheSize_ = 0;
-  pod_vector<SievingPrime> primes_;
+  Vector<SievingPrime> primes_;
   void storeSievingPrime(uint64_t, uint64_t, uint64_t);
   NOINLINE void crossOff(uint8_t*, std::size_t);
 };
