@@ -1,7 +1,7 @@
 ///
 /// @file  SievingPrimes.hpp
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -12,21 +12,20 @@
 
 #include "Erat.hpp"
 #include "macros.hpp"
-#include "pod_vector.hpp"
+#include "Vector.hpp"
 
 #include <stdint.h>
 
 namespace primesieve {
 
-class PreSieve;
 class MemoryPool;
 
 class SievingPrimes : public Erat
 {
 public:
   SievingPrimes() = default;
-  SievingPrimes(Erat*, uint64_t, PreSieve&, MemoryPool& memoryPool);
-  void init(Erat*, uint64_t, PreSieve&, MemoryPool& memoryPool);
+  SievingPrimes(Erat*, uint64_t, MemoryPool& memoryPool);
+  void init(Erat*, uint64_t, MemoryPool& memoryPool);
   uint64_t next();
 private:
   uint64_t i_ = 0;
@@ -34,8 +33,8 @@ private:
   uint64_t low_ = 0;
   uint64_t tinyIdx_ = 0;
   uint64_t sieveIdx_ = ~0ull;
-  pod_array<uint64_t, 128> primes_;
-  pod_vector<bool> tinySieve_;
+  Array<uint64_t, 128> primes_;
+  Vector<bool> tinySieve_;
   NOINLINE void fill();
   void tinySieve();
   bool sieveSegment();
