@@ -3,7 +3,7 @@
 /// @brief  The Erat class manages prime sieving using the
 ///         EratSmall, EratMedium, EratBig classes.
 ///
-/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -110,20 +110,45 @@ void Erat::initAlgorithms(uint64_t maxSieveSize,
   uint64_t minSieveSize = std::min(l1CacheSize, maxSieveSize);
 
   // ================================================================
-  // 2. sieveSize = inBetween(minSieveSize, sqrtStop, maxSieveSize)
+  // 2. sieveSize = sqrt(stop) * FACTOR_SIEVESIZE
+  // ================================================================
+
+  // Using a larger FACTOR_SIEVESIZE increases the segment size
+  // in the sieve of Eratosthenes and hence reduces the number
+  // of operations used by the algorithm. However, as a drawback
+  // a larger segment size is less cache efficient and hence
+  // performance may deteriorate on CPUs with limited L2 cache
+  // bandwidth (especially when using multi-threading).
+  uint64_t sieveSize = uint64_t(sqrtStop * config::FACTOR_SIEVESIZE);
+
+  // ================================================================
+  // 3. sieveSize = minSieveSize * x
+  // ================================================================
+
+  // The EratSmall algorithm uses minSieveSize as its segment
+  // size. If sieveSize is a multiple of minSieveSize then
+  // there will be no short segments in EratSmall which should
+  // provide optimal performance.
+  if (sieveSize > minSieveSize)
+    sieveSize = (sieveSize / minSieveSize) * minSieveSize;
+
+  // ================================================================
+  // 4. L1CacheSize <= sieveSize <= L2CacheSize
   // ================================================================
 
   // For small stop numbers a small sieve array size that
   // matches the CPU's L1 data cache size performs best.
-  // For larger stop numbers a sieve array size that is
-  // within [L1CacheSize, L2CacheSize] usually performs best.
-  uint64_t sieveSize = inBetween(minSieveSize, sqrtStop, maxSieveSize);
+  // For larger stop numbers a sieve array size that is ~
+  // L2CacheSize usually performs best. Hence our sieve size
+  // increases dynamically based on the stop number but it
+  // can never exceed the L2CacheSize (or maxSieveSize).
+  sieveSize = inBetween(minSieveSize, sieveSize, maxSieveSize);
   sieveSize = inBetween(16 << 10, sieveSize, 8192 << 10);
   sieveSize = ceilDiv(sieveSize, sizeof(uint64_t)) * sizeof(uint64_t);
   minSieveSize = std::min(l1CacheSize, sieveSize);
 
   // ================================================================
-  // 3. Initialize upper bounds for EratSmall & EratMedium
+  // 5. Initialize upper bounds for EratSmall & EratMedium
   // ================================================================
 
   // Small sieving primes are processed using the EratSmall
@@ -134,7 +159,7 @@ void Erat::initAlgorithms(uint64_t maxSieveSize,
   maxEratMedium_ = (uint64_t) (sieveSize * config::FACTOR_ERATMEDIUM);
 
   // ================================================================
-  // 4. EratBig requires a power of 2 sieve size
+  // 6. EratBig requires a power of 2 sieve size
   // ================================================================
 
   if (sqrtStop > maxEratMedium_)
@@ -146,14 +171,14 @@ void Erat::initAlgorithms(uint64_t maxSieveSize,
   }
 
   // ================================================================
-  // 5. Ensure we allocate the smallest possible amount of memory
+  // 7. Ensure we allocate the smallest possible amount of memory
   // ================================================================
 
   maxEratSmall_ = std::min(maxEratSmall_, sqrtStop);
   maxEratMedium_ = std::min(maxEratMedium_, sqrtStop);
 
   // ================================================================
-  // 6. Initialize segment bounds
+  // 8. Initialize segment bounds
   // ================================================================
 
   // The 8 bits of each byte of the sieve array correspond to
@@ -168,7 +193,7 @@ void Erat::initAlgorithms(uint64_t maxSieveSize,
   segmentHigh_ = std::min(segmentHigh_, stop_);
 
   // ================================================================
-  // 7. Use tiny sieveSize if possible
+  // 9. Use tiny sieveSize if possible
   // ================================================================
 
   // If we are sieving just a single segment
@@ -184,7 +209,7 @@ void Erat::initAlgorithms(uint64_t maxSieveSize,
   }
 
   // ================================================================
-  // 8. Finally, initialize EratSmall, EratMedium & EratBig
+  // 10. Finally, initialize EratSmall, EratMedium & EratBig
   // ================================================================
 
   ASSERT(sieveSize % sizeof(uint64_t) == 0);
