@@ -2,7 +2,7 @@
 /// @file   ParallelSieve.cpp
 /// @brief  Multi-threaded prime sieve using std::async.
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -14,7 +14,7 @@
 #include <primesieve/PrimeSieve.hpp>
 #include <primesieve/macros.hpp>
 #include <primesieve/pmath.hpp>
-#include <primesieve/pod_vector.hpp>
+#include <primesieve/Vector.hpp>
 
 #include <stdint.h>
 #include <algorithm>
@@ -83,7 +83,7 @@ uint64_t ParallelSieve::getThreadDistance(int threads) const
   ASSERT(getDistance() > 0);
 
   uint64_t dist = getDistance();
-  uint64_t balanced = isqrt(stop_) * 1000;
+  uint64_t balanced = isqrt(stop_) * 200;
   uint64_t unbalanced = dist / threads;
   uint64_t fastest = std::min(balanced, unbalanced);
   uint64_t iters = dist / fastest;
@@ -153,16 +153,6 @@ void ParallelSieve::sieve()
     auto task = [&]()
     {
       PrimeSieve ps(this);
-
-      // To improve load balancing each thread sieves many small
-      // intervals. For small intervals only basic pre-sieving
-      // is used by default to avoid initialization overhead.
-      // However here we know that many intervals will be sieved
-      // and hence there is no initialization overhead issue.
-      // Therefore we manually initialize pre-sieving.
-      PreSieve& preSieve = ps.getPreSieve();
-      preSieve.init(0, dist / threads);
-
       uint64_t i;
       counts_t counts;
       counts.fill(0);
@@ -184,7 +174,7 @@ void ParallelSieve::sieve()
       return counts;
     };
 
-    pod_vector<std::future<counts_t>> futures;
+    Vector<std::future<counts_t>> futures;
     futures.reserve(threads);
 
     for (int t = 0; t < threads; t++)
