@@ -2,7 +2,7 @@
 /// @file   count_triplets.cpp
 /// @brief  Count prime triplets inside [10^12, 10^12 + 10^9].
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -14,13 +14,11 @@
 #include <iostream>
 #include <cstdlib>
 
-using namespace std;
-
 void check(bool OK)
 {
-  cout << "   " << (OK ? "OK" : "ERROR") << "\n";
+  std::cout << "   " << (OK ? "OK" : "ERROR") << "\n";
   if (!OK)
-    exit(1);
+    std::exit(1);
 }
 
 int main()
@@ -28,11 +26,11 @@ int main()
   uint64_t start = (uint64_t) 1e12;
   uint64_t stop = (uint64_t)(1e12 + 1e9);
   uint64_t count = primesieve::count_triplets(start, stop);
-  cout << "Prime triplets inside [10^12, 10^12 + 10^9] = " << count;
+  std::cout << "Prime triplets inside [10^12, 10^12 + 10^9] = " << count;
   check(count == 271316);
 
-  cout << endl;
-  cout << "Test passed successfully!" << endl;
+  std::cout << std::endl;
+  std::cout << "Test passed successfully!" << std::endl;
 
   return 0;
 }
